@@ -1,9 +1,3 @@
-from __future__ import annotations
-# Enable using a class in type annotations in the code
-# that defines that class itself.
-# https://stackoverflow.com/a/49872353
-# Will no longer be needed in Python 3.10.
-
 import functools
 import inspect
 import logging
@@ -54,6 +48,12 @@ def full_class_name(cls):
 
 
 class Thread(threading.Thread):
+    '''
+    This class makes the result or exception produced in a thread
+    accessible from the thread object itself. This makes the `Thread`
+    object behavior somewhat similar to the `Future` object returned
+    by `concurrent.futures.ThreadPoolExecutor.submit`.
+    '''
     def run(self):
         self._result = None
         self._exc = None
@@ -62,7 +62,7 @@ class Thread(threading.Thread):
                 self._result = self._target(*self._args, **self._kwargs)
         except BaseException as e:
             self._exc = e
-            raise
+            # raise
         finally:
             # Avoid a refcycle if the thread is running a function with
             # an argument that has a member that points to the thread.
@@ -82,24 +82,39 @@ class Thread(threading.Thread):
             raise self._exc
         return self._result
 
-    def execption(self, timeout=None):
+    def exception(self, timeout=None):
         self.join(timeout)
         if self.is_alive():
             raise TimeoutError
         return self._exc
 
 
-def Process(*args, ctx, **kwargs):
-    # This is a "factory" function.
-    method = ctx.get_start_method()
-    if method == 'spawn':
-        return multiprocessing.context.SpawnProcess(*args, **kwargs)
-    if method == 'fork':
-        return multiprocessing.context.ForkProcess(*args, **kwargs)
-    assert f"multiprocessing context {ctx} not supported"
-
-
 class ProcessLogger:
+    '''
+    Logging messages produced in worker processes are tricky.
+    First, some settings should be concerned in the main process only,
+    including log formatting, log-level control, log handler (destination), etc.
+    Specifically, these should be settled in the "launching script", and definitely
+    should not be concerned in worker processes.
+    Second, the terminal printout of loggings in multiple processes tends to be
+    intermingled and mis-ordered.
+
+    This class uses a queue to transmit all logging messages that are produced
+    in a worker process to the main process/thread, to be handled there.
+
+    Usage:
+
+        1. In main process, create a `ProcessLogger` instance and start it:
+
+                pl = ProcessLogger().start()
+
+        2. Pass this object to other processes. (Yes, this object is picklable.)
+
+        3. In the other process, start it. Suppose the object is also called `pl`,
+           then do
+
+                pl.start()
+    '''
     def __init__(self, *, ctx):
         assert ctx.get_start_method() == 'spawn'
         self._ctx = ctx
@@ -121,6 +136,7 @@ class ProcessLogger:
             self._start_in_main_process()
         else:
             self._start_in_other_process()
+        return self
 
     def stop(self):
         if self._creator:
